@@ -3,7 +3,7 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "3.2.6"
+__version__ = "3.2.7"
 __all__ = ['Model', 'Wizard']
 import sys
 try:
@@ -934,7 +934,7 @@ class Wizard(object):
                 ctx['active_ids'] = None
                 ctx['active_model'] = None
             if self.action:
-                ctx['action_id'] = self.action.id
+                ctx['action_id'] = self.action['id']
             else:
                 ctx['action_id'] = None
 
@@ -956,12 +956,14 @@ class Wizard(object):
                 self.form._default_set(view['defaults'])
                 self.states = [b['state'] for b in view['buttons']]
                 self.form_state = view['state']
-                return
             else:
                 self.state = self.end_state
 
             if 'actions' in result:
                 pass  # TODO
 
+            if 'view' in result:
+                return
+
         if self.state == self.end_state:
             self._proxy.delete(self.session_id, self._config.context)
